@@ -465,16 +465,19 @@ setMethod(f="c_match_default_codes", signature=c("dimVar", "character"), definit
 
 setMethod(f="c_standardize", signature=c("dimVar", "character"), definition=function(object, input) {
   ind <- which(is.na(match(input, g_original_codes(object))))
-  if ( length(ind) > 0 ) {
+  if (length(ind) > 0) {
     matchInd <- match(input[ind], g_dups(object))
-    if ( any(is.na(matchInd)) ) {
-      stop("c_standardize: elements of 'codesOrig' not listed in 'codesOriginal' or 'dups'!\n")
+    if (any(is.na(matchInd))) {
+      probs <- unique(input[ind][is.na(matchInd)])
+      err <- paste("the following levels for dimension",shQuote(g_varname(object)))
+      err <- paste(err, "were not specified in the hierarchical definition:\n")
+      err <- paste0(err, paste("-",shQuote(probs), collapse="\n"))
+      stop(err, call.=FALSE)
     }
     input[ind] <- g_dups_up(object)[matchInd]
   }
   out <- c_match_default_codes(object, input)
-
-  if ( any(is.na(out)) ) {
+  if (any(is.na(out))) {
     stop("c_standardize:: matching not successful!\n")
   }
   return(out)
