@@ -1,21 +1,22 @@
 context("test jj_format")
-data("microData1", package = "sdcTable")
+
+utils::data("microdata1", package = "sdcTable")
 
 # create hierarchies
 dimList <- list(
-  region = hier_create(
+  region = sdcHierarchies::hier_create(
     root = "Total",
     nodes = LETTERS[1:4]
   ),
-  gender = hier_create(
+  gender = sdcHierarchies::hier_create(
     root = "Total",
-    nodes = c("male", "female")
+    nodes = c("female", "male")
   )
 )
 
 # creating an problem instance
 prob <- makeProblem(
-  data = microData1,
+  data = microdata1,
   dimList = dimList,
   numVarInd = "val"
 )
@@ -29,7 +30,7 @@ expect_identical(digest::digest(inp), "accb193e8f09427be7f8ccd1787a9815")
 
 # no numvar
 prob <- makeProblem(
-  data = microData1,
+  data = microdata1,
   dimList = dimList
 )
 inp <- createJJFormat(prob)
